<?php
/**
 * wp-smtp-contact-form is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
Contributors: westi, ryanduff, firas, ron.lievens
Plugin Name: WP SMTP Contact Form
Author URI: http://www.ronlievens.org/
Plugin URI: http://www.ronlievens.org/software/wp-smtp-contact-form/
Requires at least: 2.8
Tested up to: 2.8.6
Author: Ron Lievens
Version: 0.1
Description: Wordpress contact form that uses pear Mail and smtp.
*/
require_once(plugin_dir_path(__FILE__).'mailsender.php');
load_plugin_textdomain('wpcf',$path = 'wp-content/plugins/wp-smtp-contact-form');

function wpcf_is_malicious($input) {
    $is_malicious = false;
    $bad_inputs = array("\r", "\n", "mime-version", "content-type", "cc:", "to:");
    foreach($bad_inputs as $bad_input) {
        if(strpos(strtolower($input), strtolower($bad_input)) !== false) {
            $is_malicious = true; break;
        }
    }
    return $is_malicious;
}

/* This function checks for errors on input and changes $wpcf_strings if there are any errors.
 * Shortcircuits if there has not been a submission.
 */
function wpcf_check_input() {
    if(!(isset($_POST['wpcf_stage']))) {return false;} // Shortcircuit.

    $_POST['wpcf_your_name'] = htmlentities(stripslashes(trim($_POST['wpcf_your_name'])));
    $_POST['wpcf_your_email'] = htmlentities(stripslashes(trim($_POST['wpcf_your_email'])));
    $_POST['wpcf_website'] = htmlentities(stripslashes(trim($_POST['wpcf_website'])));
    $_POST['wpcf_msg'] = htmlentities(stripslashes(trim($_POST['wpcf_msg'])));

    global $wpcf_strings;
    $ok = true;

    if(empty($_POST['wpcf_your_name'])) {
        $ok = false; $reason = 'empty';
        $wpcf_strings['name'] = '<div class="contactright"><input type="text" name="wpcf_your_name" id="wpcf_your_name" size="30" maxlength="50" value="' . $_POST['wpcf_your_name'] . '" class="contacterror" /> (' . __('required', 'wpcf') . ')</div>';
    }

    if(!is_email($_POST['wpcf_your_email'])) {
        $ok = false; $reason = 'empty';
        $wpcf_strings['email'] = '<div class="contactright"><input type="text" name="wpcf_your_email" id="wpcf_your_email" size="30" maxlength="50" value="' . $_POST['wpcf_your_email'] . '" class="contacterror" /> (' . __('required', 'wpcf') . ')</div>';
    }

    if(empty($_POST['wpcf_msg'])) {
        $ok = false; $reason = 'empty';
        $wpcf_strings['msg'] = '<div class="contactright"><textarea name="wpcf_msg" id="wpcf_message" cols="35" rows="8" class="contacterror">' . $_POST['wpcf_msg'] . '</textarea></div>';
    }

    if(wpcf_is_malicious($_POST['wpcf_your_name']) || wpcf_is_malicious($_POST['wpcf_your_email'])) {
        $ok = false; $reason = 'malicious';
    }

    if($ok == true) {
        return true;
    }
    else {
        if($reason == 'malicious') {
            $wpcf_strings['error'] = "<div style='font-weight: bold;'>You can not use any of the following in the Name or Email fields: a linebreak, or the phrases 'mime-version', 'content-type', 'cc:' or 'to:'.</div>";
        } elseif($reason == 'empty') {
            $wpcf_strings['error'] = '<div style="font-weight: bold;">' . stripslashes(get_option('wpcf_error_msg')) . '</div>';
        }
        return false;
    }
}

/*Wrapper function which calls the form.*/
function wpcf_callback( $content ) {
    global $wpcf_strings;

	/* Run the input check. */
    if(false === strpos($content, '<!--contact form-->')) {
        return $content;
    }

    /* Declare strings that change depending on input. This also resets them so errors clear on resubmission. */
    $wpcf_strings = array(
        'name' => '<div class="contactright"><input type="text" name="wpcf_your_name" id="wpcf_your_name" size="30" maxlength="50" value="' . (isset($_POST['wpcf_your_name']) ? $_POST['wpcf_your_name'] :'') . '" /> (' . __('required', 'wpcf') . ')</div>',
        'email' => '<div class="contactright"><input type="text" name="wpcf_your_email" id="wpcf_your_email" size="30" maxlength="50" value="' . (isset($_POST['wpcf_your_email']) ? $_POST['wpcf_your_email'] : '') . '" /> (' . __('required', 'wpcf') . ')</div>',
        'msg' => '<div class="contactright"><textarea name="wpcf_msg" id="wpcf_msg" cols="35" rows="8" >' . (isset($_POST['wpcf_msg']) ? $_POST['wpcf_msg'] : '' ) . '</textarea></div>',
        'error' => '');

    if(wpcf_check_input()) // If the input check returns true (ie. there has been a submission & input is ok)
    {
        $smtpd = get_option('wpcf_smtpd');
        $to = get_option('wpcf_email');
        $subject = get_option('wpcf_subject');
        $success_msg = get_option('wpcf_success_msg');
        $success_msg = stripslashes($success_msg);
        $error_msg = get_option('wpcf_error_msg');
        $error_msg = stripslashes($error_msg);

        $name = $_POST['wpcf_your_name'];
        $email = $_POST['wpcf_your_email'];
        $website = $_POST['wpcf_website'];
        $msg = $_POST['wpcf_msg'];

        $fullmsg = $name."[".$email."] wrote:<br>\n<br>\n<p>".$msg."</p>\n<br>\nWebsite: ".$website."<br>\nIP: ".getip();

        if (smtp_mail($smtpd, $to, $subject, $fullmsg)) {
            $results = '<div style="font-weight: bold;">'.$success_msg.'</div>';
        } else {
            $results = '<div style="font-weight: bold;">'.$error_msg.'</div>';
        }
        echo $results;
    }
    else // Else show the form. If there are errors the strings will have updated during running the inputcheck.
    {
        $form = '<div class="contactform">
        ' . $wpcf_strings['error'] . '
        	<form action="' . get_permalink() . '" method="post">
        		<div class="contactleft"><label for="wpcf_your_name">' . __('Your Name: ', 'wpcf') . '</label></div>' . $wpcf_strings['name']  . '
        		<div class="contactleft"><label for="wpcf_your_email">' . __('Your Email:', 'wpcf') . '</label></div>' . $wpcf_strings['email'] . '
        		<div class="contactleft"><label for="wpcf_website">' . __('Your Website:', 'wpcf') . '</label></div><div class="contactright"><input type="text" name="wpcf_website" id="wpcf_website" size="30" maxlength="100" value="' . (isset($_POST['wpcf_website']) ? $_POST['wpcf_website'] : '') . '" /></div>
            	<div class="contactleft"><label for="wpcf_msg">' . __('Your Message: ', 'wpcf') . '</label></div>' . $wpcf_strings['msg'] . '
            	<div class="contactright"><input type="submit" name="Submit" value="' . __('Submit', 'wpcf') . '" id="contactsubmit" /><input type="hidden" name="wpcf_stage" value="process" /></div>
        	</form>
        </div>
        <div style="clear:both; height:1px;">&nbsp;</div>';
        return str_replace('<!--contact form-->', $form, $content);
    }
}


/*Can't use WP's function here, so lets use our own*/
function getip() {
    if (isset($_SERVER)) {
        if (isset($_SERVER["HTTP_X_FORWARDED_FOR"])) {
            $ip_addr = $_SERVER["HTTP_X_FORWARDED_FOR"];
        }
        elseif (isset($_SERVER["HTTP_CLIENT_IP"])) {
            $ip_addr = $_SERVER["HTTP_CLIENT_IP"];
        }
        else {
            $ip_addr = $_SERVER["REMOTE_ADDR"];
        }
    }
    else {
        if ( getenv( 'HTTP_X_FORWARDED_FOR' ) ) {
            $ip_addr = getenv( 'HTTP_X_FORWARDED_FOR' );
        }
        elseif ( getenv( 'HTTP_CLIENT_IP' ) ) {
            $ip_addr = getenv( 'HTTP_CLIENT_IP' );
        }
        else {
            $ip_addr = getenv( 'REMOTE_ADDR' );
        }
    }
    return $ip_addr;
}


/*CSS Styling*/
function wpcf_css() {
    ?>
<style type="text/css" media="screen">

    /* Begin Contact Form CSS */
    .contactform {
        position: static;
        overflow: hidden;
        width: 95%;
    }

    .contactleft {
        width: 25%;
        white-space: pre;
        text-align: right;
        clear: both;
        float: left;
        display: inline;
        padding: 4px;
        margin: 5px 0;
    }

    .contactright {
        width: 70%;
        text-align: left;
        float: right;
        display: inline;
        padding: 4px;
        margin: 5px 0;
    }

    .contacterror {
        border: 1px solid #ff0000;
    }

    .contactsubmit {
    }
    /* End Contact Form CSS */

</style>

<?php

}

function wpcf_add_options_page() {
    add_options_page(__('Contact Form Options', 'wpcf'), __('Contact Form', 'wpcf'), 'manage_options', 'wp-smtp-contact-form/options-contactform.php');
}

/* Action calls for all functions */
add_action('admin_menu', 'wpcf_add_options_page');
add_filter('wp_head', 'wpcf_css');
add_filter('the_content', 'wpcf_callback', 7);
?>
